==> FEUNotification-0.1.0.zip: FEUNotification/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'FEUNotification';
$lang['postinstall'] = 'Be sure to set "Use FEUNotification" permissions to use this module!';
$lang['postuninstall'] = 'Module Uninstalled.';
$lang['really_uninstall'] = 'Really? You\'re sure you want to uninstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['moddescription'] = '...';
$lang['accessdenied'] = 'Right needed to access this zone';
$lang['title_general'] ='Notification Tool';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>For the users preferences, you can use {FEUNotification} to show the control pannel. To get the cron url, you can use {FEUNotification action="sendurl"}.</p>
';
$lang['subject'] = 'subject ... ';
$lang['body'] = 'body...';
$lang['empty_list'] = 'No more modules wich you can subscribe to';

$lang['module_name'] = 'Module name';
$lang['template_name'] = 'Template name';
$lang['title_add_template'] = 'Add template';
$lang['template_title'] = 'Template name';
$lang['template_code'] = 'Template code';
$lang['template'] = 'Template';
$lang['templates'] = 'Templates';
$lang['is_active'] = 'Is active';
$lang['edit'] = 'Edit';
$lang['delete'] = 'Delete';
$lang['areyousure'] = 'Are you sure?';
$lang['params'] = 'Parameters';
$lang['manage %module% notifications'] = 'Manage %module% notifications';
$lang['cancel'] = 'Cancel';
$lang['submit'] = 'Submit';
$lang['apply'] = 'Apply';
$lang['mustbeconnected'] = 'You must be connected.';
$lang['update'] = 'Update';
$lang['send_updates'] = 'Send updates';
$lang['preferences'] = 'Preferences';
$lang['logs'] = 'Logs';
$lang['email_subject'] = 'Email subject';
$lang['email_template'] = 'Email template';
$lang['send_emails'] = 'Send emails';
$lang['send_email_test'] = 'Send email test';
$lang['send'] = 'Send';
$lang['view_log'] = 'View log';
$lang['date'] = 'Date';
$lang['title'] = 'Title';
$lang['details'] = 'Details';
$lang['back_to_list'] = 'Back to the list';
$lang['send_key'] = 'Send key';
?>

==> FEUNotification-0.1.1.zip: FEUNotification/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'FEUNotification';
$lang['postinstall'] = 'Be sure to set "Use FEUNotification" permissions to use this module!';
$lang['postuninstall'] = 'Module Uninstalled.';
$lang['really_uninstall'] = 'Really? You\'re sure you want to uninstall this fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['moddescription'] = '...';
$lang['accessdenied'] = 'Right needed to access this zone';
$lang['title_general'] ='Notification Tool';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>For the users preferences, you can use {FEUNotification} to show the control pannel.</p>
<p>To make it work, you have to configure the module Cron correctly.</p>
';
$lang['subject'] = 'subject ... ';
$lang['body'] = 'body...';
$lang['empty_list'] = 'No more modules wich you can subscribe to';

$lang['module_name'] = 'Module name';
$lang['template_name'] = 'Template name';
$lang['title_add_template'] = 'Add template';
$lang['template_title'] = 'Template name';
$lang['template_code'] = 'Template code';
$lang['template'] = 'Template';
$lang['templates'] = 'Templates';
$lang['is_active'] = 'Is active';
$lang['edit'] = 'Edit';
$lang['delete'] = 'Delete';
$lang['areyousure'] = 'Are you sure?';
$lang['params'] = 'Parameters';
$lang['manage %module% notifications'] = 'Manage %module% notifications';
$lang['cancel'] = 'Cancel';
$lang['submit'] = 'Submit';
$lang['apply'] = 'Apply';
$lang['mustbeconnected'] = 'You must be connected.';
$lang['update'] = 'Update';
$lang['send_updates'] = 'Send updates';
$lang['preferences'] = 'Preferences';
$lang['logs'] = 'Logs';
$lang['email_subject'] = 'Email subject';
$lang['email_template'] = 'Email template';
$lang['send_emails'] = 'Send emails';
$lang['send_email_test'] = 'Send email test';
$lang['send'] = 'Send';
$lang['view_log'] = 'View log';
$lang['date'] = 'Date';
$lang['title'] = 'Title';
$lang['details'] = 'Details';
$lang['back_to_list'] = 'Back to the list';
$lang['send_key'] = 'Send key';

$lang['sent_log'] = 'Notifications sent for the following periods: %s';
?>
